@@ -10,12 +10,7 @@ from ddbcereal import Deserializer, Serializer
 from ddbcereal.types import PythonNumber
 from requests import RequestException
 
-from dynamodb_python.utils import (
-    get_logical_operation,
-    make_expression,
-    normalize_dynamodb_write,
-    split_list,
-)
+from .utils import get_logical_operation, make_expression, normalize_dynamodb_write, split_list
 
 
 @dataclass()
